##############################################################
# Replication file for 
# Moral Hazard: German Public Opinion on the Greek Debt Crisis
# Brian C. Rathbun, Kathleen E. Powers, and Therese Anders
# 18/09/04
##############################################################

#rm(list = ls())
library(foreign)
library(exactRankTests)
library(mediation)
library(sandwich)
library(psych)
library(stargazer)
library(arm)
library(ggplot2)
library(Matching)
library(sm)
#library(plyr)
library(dplyr)
library(tidyr)
library(coefplot)
library(grid)
library(scales)
library(interplot)
library(readstata13)
library(stringr)
library(interplot)
library(lmtest)
library(gridExtra)
library(RCurl)
library(interflex)

##Set your working directory before loading the data##
#setwd()

data <- read.dta13("RathbunPowersAnders Moral Hazard Replication Data.dta")

###########################
#
# A) Main text
#
###########################

## Creating additional variables 
# East/West dummy - Berlin is region 6
# Also creating continuous measure of party identification using infratest dimap

data <- data %>%
  dplyr::mutate(east = ifelse((reg_6 | reg_7 == 1 | reg_8 == 1), 1, 0)) %>%
  dplyr::mutate(east_noberlin = ifelse((reg_7 == 1 | reg_8 == 1), 1, 0)) %>%
  dplyr::mutate(pid_cont = ifelse(pid_1 == 1, 5.8, NA),
                pid_cont = replace(pid_cont, pid_2 == 1, 4.7),
                pid_cont = replace(pid_cont, pid_3 == 1, 2.9),
                pid_cont = replace(pid_cont, pid_4 == 1, 4.3),
                pid_cont = replace(pid_cont, pid_5 == 1, 5.6),
                pid_cont = replace(pid_cont, pid_6 == 1, 8.3)) %>%
  dplyr::mutate(catholic = ifelse((loc_1 == 1 | loc_2 == 1 | loc_10 == 1 | loc_12 == 1 | loc_11 == 1), 1, 0),
                protestant = ifelse((loc_7 == 1 | loc_9 == 1 | loc_15 == 1), 1, 0),
                nonchristian = ifelse((loc_3 == 1 | loc_4 == 1 | loc_5 == 1 | loc_6 == 1 | loc_8 == 1 | loc_13 == 1 | loc_14 == 1 | loc_16) == 1, 1, 0))


####Figure 1####
# Note: selecting cases that have a valid response on national attachment question. 
# This represents the portion of respondents who completed the full survey, used in subsequent analyses
names(data)
data_sub <- data %>%
  dplyr::select(responseid,
                bailout1st,
                austerity1st,
                debtrelief1st,
                natid)
data_sub$complete <- complete.cases(data_sub)

data_sub <- data_sub %>%
  filter(complete == TRUE) %>%
  dplyr::select(-complete,
                -natid) #N = 1000 

data_sub_long <- data_sub %>%
  gather(variable, value, bailout1st:debtrelief1st) %>%
  arrange(value)

table(data_sub_long$value)
data_sub_long$value_fac <- factor(data_sub_long$value,
                                  levels = seq(6, 1),
                                  labels = rev(c("Oppose Strongly",
                                                 "Oppose",
                                                 "Oppose Somewhat",
                                                 "Support Somewhat",
                                                 "Support",
                                                 "Support Strongly")))


table(data_sub_long$variable)
data_sub_long$variable <- factor(data_sub_long$variable, 
                                 levels = c("bailout1st",
                                            "austerity1st",
                                            "debtrelief1st"),
                                 labels = c("Bailout",
                                            "Austerity",
                                            "Debt Relief"))
## Stacked barplot
# To be able to display percentages, re-formatting the data
names(data_sub_long)
tab_sum <- data_sub_long %>%
  dplyr::count(variable,value_fac) %>%
  mutate(perc = 100/1000*n)

# Note: the plot below uses the grid and scales packages as well as ggplot2
ggplot(tab_sum, aes(x = variable, y = n, fill = value_fac)) +
  geom_bar(position = "fill",stat = "identity", width = 0.5) +
  scale_y_continuous(labels = percent_format(), expand = c(0, 0)) +
  scale_x_discrete(expand = c(0, 0)) +
  labs(x = "", y = "Percent of respondents") +
  theme_minimal() + 
  scale_fill_grey(name = "Response", start = 0.8, end = 0.1) +
  theme(axis.text.x  = element_text(size = 12, face="bold"),
        axis.text.y = element_text(size = 8),
        axis.title.y = element_text(size = 10),
        axis.ticks.x = element_blank(),
        axis.ticks.y = element_line(),
        panel.grid = element_blank(), 
        panel.border=element_blank(),
        legend.title = element_text(face = "bold"))

# saving it
# ggsave(filename = "dvdist.jpg",
#        width = 6,
#        height = 3)




####Table 1: Predicting Bailout, Austerity, and Debt Relief Attitudes####
##Support for Bailout##
#Moral Values Only
mod.bail1.rf1_nointmin <- lm(bailout1st_01 ~ harm_01 + fair_01 + auth_01 + natid_01 + eurid_01, data=data)
mod.bail1.rf1 <- lm(bailout1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01, data=data)

#Including Controls: Demographics, Economic Self-interest, Identity, Region Fixed Effects
mod.bail1.rf2 <- lm(bailout1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)

#Including Controls: Trade ties instead of employment status (separate model due to branching in survey and resulting collinearity)
mod.bail1.rf3 <- lm(bailout1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 +  pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + trade_1 + trade_3 + trade_4 + trade_5 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.bail1.rf3)


##Austerity##
#Moral Values Only
mod.aust1.rf1_nointmin <- lm(austerity1st_01 ~ harm_01 + fair_01 + auth_01 + natid_01 + eurid_01, data=data)
mod.aust1.rf1 <- lm(austerity1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01, data=data)

#Including Controls: Demographics, Economic Self-interest, Identity, Region Fixed Effects
mod.aust1.rf2 <- lm(austerity1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)

#Including Controls: Trade ties instead of employment status (separate model due to branching in survey and resulting collinearity)
mod.aust1.rf3 <- lm(austerity1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + trade_1 + trade_3 + trade_4 + trade_5 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)

##Debt Relief##
#Moral Values Only
mod.debt1.rf1_nointmin <- lm(debtrelief1st_01 ~ harm_01 + fair_01 + auth_01 + natid_01 + eurid_01, data=data)
mod.debt1.rf1 <- lm(debtrelief1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01, data=data)

#Including Controls: Demographics, Economic Self-interest, Identity, Region Fixed Effects
mod.debt1.rf2 <- lm(debtrelief1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)


#Including Controls: Trade ties instead of employment status (separate model due to branching in survey and resulting collinearity)
mod.debt1.rf3 <- lm(debtrelief1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + trade_1 + trade_3 + trade_4 + trade_5 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)


## TABLE 1
## Main manuscript: reduced table output; Appendix: full table
# Note: The stargazer output was manually adjusted for inclusion in the manuscript/appendix.
# All changes are documented in the table caption.
stargazer(mod.bail1.rf1_nointmin, mod.bail1.rf1, mod.bail1.rf2, mod.bail1.rf3,
          mod.aust1.rf1_nointmin, mod.aust1.rf1, mod.aust1.rf2, mod.aust1.rf3, 
          mod.debt1.rf1_nointmin, mod.debt1.rf1, mod.debt1.rf2, mod.debt1.rf3, 
          title="Correlates of Support for Bailout, Austerity, and Debt Forgiveness", 
          omit.stat=c("LL", "ser", "f"), 
          style="apsr", 
          digits = 3, 
          label = "tab:suppreg1",
          column.sep.width = "-5pt",
          font.size = "tiny",
          column.labels = c("Support Bailout", "Support Austerity Requirement", "Support Debt Forgiveness"),
          column.separate = c(4, 4, 4),
          dep.var.labels.include = FALSE,
          covariate.labels=c("Caring", 
                             "Authority", 
                             "National Attachment", 
                             "European Attachment", 
                             "Fairness", 
                             "Retribution",
                             "Fairness $\\times$ Retribution",
                             "Cosmopolitanism", 
                             "Knowledge", 
                             "Interest", 
                             "SPD", 
                             "Linke", 
                             "Gruene", 
                             "FPD", 
                             "AfD", 
                             "Other Party", 
                             "Age", 
                             "Male", 
                             "Owns Stocks", 
                             "Secondary Educ. Certificate", 
                             "Higher Educ. Certificate", 
                             "Completed Vocational Training",
                             "Completed University", 
                             "15000-29999\\EUR", 
                             "30000-49999\\EUR", 
                             "50000-99999\\EUR", 
                             "Over 100000\\EUR", 
                             "Full Time", 
                             "Part Time", 
                             "Student", 
                             "Retired", 
                             "Missing Trade Ties", 
                             "Weak Trade Ties", 
                             "Strong Trade Ties",
                             "Very Strong Trade Ties", 
                             "Regulation Important", 
                             "More State Services",
                             "Region 1",
                             "Region 2",
                             "Region 3",
                             "Region 4",
                             "Region 5",
                             "Region 7",
                             "Region 8"), 
          add.lines = list(c("Controls (Employment)", rep(c("", "", "\\checkmark", ""), 4)),
                           c("Controls (Trade ties)", rep(c("", "", "", "\\checkmark"), 4))),
          order = c(1, 3, 5, 6, 2, 4, 44),  
          star.char = c("*", "**"), 
          star.cutoffs = c(0.05, 0.01), 
          notes.append = FALSE, 
          notes = c("*p$<$0.05; **p$<$0.01",
                    "Table displays OLS coefficients with standard errors in parentheses.",
                    "All measures, except for age, have been rescaled to range from 0 to 1.",
                    "Reference categories are unemployed, CDU/CSU, under 15000\\EUR, no trade ties,",
                    "lower secondary education or less, and Berlin. Models 4, 8, and 12 include a",
                    "trade ties missing dummy variable."))



##Figure 2 ---------------------------------
#Interaction between fairness and retribution

#Bailout
interplot(m = mod.bail1.rf2, var1 = "fair_01", var2 = "retrib_01", plot = FALSE)
p.bail.fr <- interplot(m = mod.bail1.rf2, var1="fair_01", var2 = "retrib_01", esize = 1.2) + 
  ylab("Effect of Fairness") + 
  theme_bw() + 
  theme(plot.margin = unit(c(1,1,1.5,1.2),"cm")) + 
  geom_hline(yintercept = 0, linetype="dashed") + 
  ggtitle("a) Bailout")
p.bail.fr2 <- p.bail.fr + 
  scale_x_continuous(name = "Retribution", limits = c(0, 1)) + 
  scale_y_continuous(limits = c(-1,1.09)) +
  theme(axis.title.x = element_text(size=22), 
        axis.title.y = element_text(size=22), 
        axis.text.x = element_text(size=16, colour="black"), 
        axis.text.y = element_text(size=16, colour="black"),
        plot.title = element_text(size=22, colour="black", hjust = 0.5))
#View Plot
p.bail.fr2

#Austerity
interplot(m=mod.aust1.rf2, var1="fair_01", var2="retrib_01", plot=FALSE)
p.aust.fr <- interplot(m=mod.aust1.rf2, var1="fair_01", var2="retrib_01", esize=1.2) + 
  theme_bw() + 
  theme(plot.margin=unit(c(1,1,1.5,1.2),"cm")) + 
  geom_hline(yintercept=0, linetype="dashed") + 
  ggtitle("b) Austerity")
p.aust.fr2 <- p.aust.fr + 
  scale_x_continuous(name="Retribution", limits=c(0, 1)) + 
  scale_y_continuous(limits=c(-1,1.09)) +
  theme(axis.title.x = element_text(size=22), 
        axis.title.y = element_text(size=22), 
        axis.text.x = element_text(size=16, colour="black"), 
        axis.text.y=element_text(size=16, colour="black"),
        plot.title = element_text(size=22, colour="black", hjust=0.5))
#View Plot
p.aust.fr2

#Debt Relief
interplot(m=mod.debt1.rf2, var1="fair_01", var2="retrib_01")
p.debt.fr <- interplot(m=mod.debt1.rf2, var1="fair_01", var2="retrib_01", esize=1.2) +
  theme_bw() + 
  theme(plot.margin=unit(c(1,1,1.5,1.2),"cm")) + 
  geom_hline(yintercept=0, linetype="dashed") + 
  ggtitle("c) Debt Relief")
p.debt.fr2 <- p.debt.fr + scale_x_continuous(name="Retribution", limits=c(0, 1)) + 
  scale_y_continuous(limits=c(-1, 1.09)) +
  theme(axis.title.x = element_text(size=22), 
        axis.title.y = element_text(size=22), 
        axis.text.x = element_text(size=16, colour="black"), 
        axis.text.y=element_text(size=16, colour="black"),
        plot.title = element_text(size=22, colour="black", hjust=0.5))
#View Plot
p.debt.fr2

#Arrange plots into a row for a single figure
grid.arrange(p.bail.fr2, p.aust.fr2, p.debt.fr2, ncol = 3)






# Figure 3 ----------------------------------------------------------------
###The Effect of Caring Conditional on National Attachment

#Bailout#
mod.carenat.lm  <- lm(bailout1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + natid_01 + harm_01*natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)

#Austerity#
mod.carenataust.lm  <- lm(austerity1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + natid_01 + harm_01*natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)

#Debt Relief#
mod.carenatdebt.lm  <- lm(debtrelief1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + natid_01 + harm_01*natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)

#Bailout
interplot(m=mod.carenat.lm, var1="harm_01", var2="natid_01", esize=1.3, point = T)
#Formatted for manuscript
cbp <- interplot(m=mod.carenat.lm, 
                 var1="harm_01", 
                 var2="natid_01", 
                 esize=1.2, 
                 point = T) +
  geom_point(size=4) +
  ylab("Effect of Caring") +
  theme_bw() +
  theme(plot.margin=unit(c(1,1,1.5,1.2),"cm")) +
  geom_hline(yintercept=0, linetype="dashed") +
  ggtitle("a) Bailout")
cbp2 <- cbp +
  scale_x_continuous(name="National Attachment",
                     limits=c(0, 1),
                     breaks=c(0, .167, 0.33, 0.5, 0.67, 0.83, 1),
                     labels=c("0", "0.17", "0.33", "0.5", "0.67", "0.83", "1")) +
  scale_y_continuous(limits=c(-.6,0.8)) +
  theme(axis.title.x = element_text(size=22),
        axis.title.y = element_text(size=22),
        axis.text.x = element_text(size=16, colour="black"),
        axis.text.y=element_text(size=16, colour="black"),
        plot.title = element_text(size=22, colour="black", hjust=0.5))
#View Plot
cbp2

#Austerity
interplot(m=mod.carenataust.lm, var1="harm_01", var2="natid_01")
cap <- interplot(m=mod.carenataust.lm, 
                 var1="harm_01", 
                 var2="natid_01", 
                 esize=1.2, 
                 point = T) +
  geom_point(size=4) +
  theme_bw() +
  theme(plot.margin=unit(c(1,1,1.5,1.2),"cm")) +
  geom_hline(yintercept=0, linetype="dashed") +
  ggtitle("b) Austerity")
cap2 <- cap +
  scale_x_continuous(name="National Attachment",
                     limits=c(0, 1),
                     breaks=c(0, .17, 0.33, 0.5, 0.67, 0.83, 1),
                     labels=c("0", "0.17", "0.33", "0.5", "0.67", "0.83", "1")) +
  scale_y_continuous(limits=c(-.6,0.8)) +
  theme(axis.title.x = element_text(size=22),
        axis.title.y = element_text(size=22),
        axis.text.x = element_text(size=16, colour="black"),
        axis.text.y=element_text(size=16, colour="black"),
        plot.title = element_text(size=22, colour="black", hjust=0.5))
#View Plot
cap2

#Debt Relief
interplot(m=mod.carenatdebt.lm, var1="harm_01", var2="natid_01")
#Formatted for manuscript
cdp <- interplot(m=mod.carenatdebt.lm, 
                 var1="harm_01", 
                 var2="natid_01", 
                 esize=1.2, 
                 point = T) +
  geom_point(size=4) +
  theme_bw() +
  theme(plot.margin=unit(c(1,1,1.5,1.2),"cm")) +
  geom_hline(yintercept = 0, linetype="dashed") +
  ggtitle("c) Debt Relief")
cdp2 <- cdp +
  scale_x_continuous(name="National Attachment",
                     limits=c(0, 1),
                     breaks=c(0, .17, 0.33, 0.5, 0.67, 0.83, 1),
                     labels=c("0", "0.17", "0.33", "0.5", "0.67", "0.83", "1")) +
  scale_y_continuous(limits=c(-.6,0.8)) +
  theme(axis.title.x = element_text(size=22),
        axis.title.y = element_text(size=22),
        axis.text.x = element_text(size=16, colour="black"),
        axis.text.y=element_text(size=16, colour="black"),
        plot.title = element_text(size=22, colour="black", hjust=0.5))
#View Plot
cdp2

#Put the plots together in a single row
grid.arrange(cbp2, cap2, cdp2, ncol=3)



# Appendix: Table 14 ------------------------------------------------------

# Produces a mostly-formatted .tex table
# Some model output omitted for presentation (controls)
stargazer(mod.carenat.lm,
          mod.carenataust.lm,
          mod.carenatdebt.lm,
          title="Does the Effect of Caring Depend on Identity?",
          omit.stat=c("LL", "ser", "f"),
          style="apsr",
          digits=3,
          label="tab:carenat",
          covariate.labels=c("Caring",
                             "Fairness",
                             "Authority",
                             "retrib_ution",
                             "National Attachment",
                             "European Attachment",
                             "Cosmopolitanism",
                             "Knowledge",
                             "Interest"),
          star.cutoffs=c(0.05, 0.01))


# Figure 4 ----------------------------------------------------------------

#The Effect of Fairness Conditional on National Attachment
##National Attachment##
#Bailout#
mod.fairnat.lm  <- lm(bailout1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + natid_01 + fair_01*natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)

#Austerity#
mod.fairnataust.lm  <- lm(austerity1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + natid_01 + fair_01*natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)

#Debt Relief#
mod.fairnatdebt.lm  <- lm(debtrelief1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + natid_01 + fair_01*natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)

#Bailout
interplot(m=mod.fairnat.lm, var1="fair_01", var2="natid_01", esize=1.3) 
#Formatted for manuscript
fbp <- interplot(m=mod.fairnat.lm, 
                 var1="fair_01", 
                 var2="natid_01", 
                 esize=1.2, 
                 point = T) + 
  geom_point(size=4) + 
  ylab("Effect of Fairness") + 
  theme_bw() + 
  theme(plot.margin=unit(c(1,1,1.5,1.2),"cm")) + 
  geom_hline(yintercept=0, linetype="dashed") + 
  ggtitle("a) Bailout")
fbp2 <- fbp + 
  scale_x_continuous(name="National Attachment", 
                     limits=c(0, 1), 
                     breaks=c(0, .167, 0.33, 0.5, 0.67, 0.83, 1), 
                     labels=c("0", "0.17", "0.33", "0.5", "0.67", "0.83", "1")) + 
  scale_y_continuous(limits=c(-.6,0.8)) +
  theme(axis.title.x = element_text(size=22), 
        axis.title.y = element_text(size=22), 
        axis.text.x = element_text(size=16, colour="black"), 
        axis.text.y=element_text(size=16, colour="black"),
        plot.title = element_text(size=22, colour="black", hjust=0.5))
#View Plot
fbp2

#Austerity
interplot(m=mod.fairnataust.lm, var1="fair_01", var2="natid_01")
#Formatted for manuscript
fap <- interplot(m=mod.fairnataust.lm, 
                 var1="fair_01", 
                 var2="natid_01", 
                 esize=1.2,
                 point = T) + 
  geom_point(size=4) + 
  theme_bw() + 
  theme(plot.margin=unit(c(1,1,1.5,1.2),"cm")) + 
  geom_hline(yintercept=0, linetype="dashed") + 
  ggtitle("b) Austerity")
fap2 <- fap + 
  scale_x_continuous(name="National Attachment", 
                     limits=c(0, 1), 
                     breaks=c(0, .17, 0.33, 0.5, 0.67, 0.83, 1), 
                     labels=c("0", "0.17", "0.33", "0.5", "0.67", "0.83", "1")) + 
  scale_y_continuous(limits=c(-.6,0.8)) +
  theme(axis.title.x = element_text(size=22), 
        axis.title.y = element_text(size=22), 
        axis.text.x = element_text(size=16, colour="black"), 
        axis.text.y=element_text(size=16, colour="black"),
        plot.title = element_text(size=22, colour="black", hjust=0.5))
#View Plot
fap2

#Debt Relief
interplot(m=mod.fairnatdebt.lm, var1="fair_01", var2="natid_01")
#Formatted for manuscript
fdp <- interplot(m=mod.fairnatdebt.lm, 
                 var1="fair_01", 
                 var2="natid_01", 
                 esize=1.2,
                 point = T) + 
  geom_point(size=4) + 
  theme_bw() + 
  theme(plot.margin=unit(c(1,1,1.5,1.2),"cm")) + 
  geom_hline(yintercept=0, linetype="dashed") + 
  ggtitle("c) Debt Relief")
fdp2 <- fdp + 
  scale_x_continuous(name="National Attachment", 
                     limits=c(0, 1), 
                     breaks=c(0, .17, 0.33, 0.5, 0.67, 0.83, 1), 
                     labels=c("0", "0.17", "0.33", "0.5", "0.67", "0.83", "1")) + 
  scale_y_continuous(limits=c(-.6,0.8)) +
  theme(axis.title.x = element_text(size=22), 
        axis.title.y = element_text(size=22), 
        axis.text.x = element_text(size=16, colour="black"), 
        axis.text.y=element_text(size=16, colour="black"),
        plot.title = element_text(size=22, colour="black", hjust=0.5))
#View Plot
fdp2

#Place plots together in a single row
grid.arrange(fbp2, fap2, fdp2, ncol = 3)

# Appendix Table 15 -------------------------------------------------------
# Produces a mostly-formatted .tex table
# Some model output omitted for presentation (controls)
stargazer(mod.fairnat.lm, 
          mod.fairnataust.lm, 
          mod.fairnatdebt.lm, 
          title="Does the Effect of Fairness Depend on Identity?", 
          omit.stat=c("LL", "ser", "f"), 
          style="apsr", 
          digits=3, 
          label="tab:fairnat",
          covariate.labels=c("Caring", 
                             "Fairness", 
                             "Authority", 
                             "Retribution", 
                             "National Attachment", 
                             "European Attachment", 
                             "Cosmopolitanism", 
                             "Knowledge", 
                             "Interest"), 
          star.cutoffs=c(0.05, 0.01))




########### B) Appendix ##########


# Appendix Table 6 --------------------------------------------------------
# Table 6: 
#Ordered Logit Robustness check#
#DVs as factors
data$bailout1st_f <- factor(data$bailout1st_01)
data$austerity1st_f <- factor(data$austerity1st_01)
data$debtrelief1st_f <- factor(data$debtrelief1st_01)


##Support for Bailout##
#Moral Values Only
o.mod.bail1.1 <- polr(bailout1st_f ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01, data=data, Hess=TRUE)
summary(o.mod.bail1.1) 

#Including Controls: Demographics, Economic Self-interest, Identity, Region Fixed Effects
o.mod.bail1.2 <- polr(bailout1st_f ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data, Hess=TRUE)
summary(o.mod.bail1.2)

#Including Controls: Trade ties instead of employment status (separate model due to branching in survey and resulting collinearity)
o.mod.bail1.3 <- polr(bailout1st_f ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 +  pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + trade_1 + trade_3 + trade_4 + trade_5 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data, Hess=TRUE)
summary(o.mod.bail1.3)


##Austerity##
#Moral Values Only
o.mod.aust1.1 <- polr(austerity1st_f ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01, data=data, Hess=TRUE)
summary(o.mod.aust1.1) 

#Including Controls: Demographics, Economic Self-interest, Identity, Region Fixed Effects
o.mod.aust1.2 <- polr(austerity1st_f ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data, Hess=TRUE)
summary(o.mod.aust1.2)

#Including Controls: Trade ties instead of employment status (separate model due to branching in survey and resulting collinearity)
o.mod.aust1.3 <- polr(austerity1st_f ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + trade_1 + trade_3 + trade_4 + trade_5 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data, Hess=TRUE)
summary(o.mod.aust1.3)

##Debt Relief##
#Moral Values Only
o.mod.debt1.1 <- polr(debtrelief1st_f ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01, data=data, Hess=TRUE)
summary(o.mod.debt1.1) 

#Including Controls: Demographics, Economic Self-interest, Identity, Region Fixed Effects
o.mod.debt1.2 <- polr(debtrelief1st_f ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data, Hess=TRUE)
summary(o.mod.debt1.2)

#Including Controls: Trade ties instead of employment status (separate model due to branching in survey and resulting collinearity)
o.mod.debt1.3 <- polr(debtrelief1st_f ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + trade_1 + trade_3 + trade_4 + trade_5 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data, Hess=TRUE)
summary(o.mod.debt1.3)

#Produces a mostly-formatted .tex table
stargazer(o.mod.bail1.1, o.mod.bail1.2, o.mod.bail1.3, 
          o.mod.aust1.1, o.mod.aust1.2, o.mod.aust1.3, 
          o.mod.debt1.1, o.mod.debt1.2, o.mod.debt1.3, 
          title="Correlates of Support for Bailout, Austerity, and Debt Forgiveness", 
          omit.stat=c("LL", "ser", "f"), 
          style="apsr", 
          digits=3, 
          label="tab:suppreg1",
          covariate.labels=c("Caring", 
                             "Fairness", 
                             "Authority", 
                             "Retribution", 
                             "National Attachment", 
                             "European Attachment", 
                             "Cosmopolitanism", 
                             "Knowledge", 
                             "Interest", 
                             "SPD", 
                             "Linke", 
                             "Gr\"{u}ne", 
                             "FPD", 
                             "AfD", 
                             "Other Party", 
                             "Age", 
                             "Male", 
                             "Owns Stocks", 
                             "Secondary Educ. Certificate", 
                             "Higher Educ. Certificate", 
                             "Completed Vocational Training",
                             "Completed University", "15000-29999{euro}", 
                             "30000-49999{euro}", 
                             "50000-99999{euro}", 
                             "Over 100000{euro}", 
                             "Full Time", 
                             "Part Time", 
                             "Student", 
                             "Retired", 
                             "trade_1", 
                             "Weak Trade Ties", 
                             "Strong Trade Ties",
                             "Very Strong Trade Ties", 
                             "Regulation Important", 
                             "More State Services"), 
          star.cutoffs=c(0.05, 0.01))

# Appendix Table 7: ---------------
###Robustness Check: Cluster Standard Errors by region### 
url_robust <- "https://raw.githubusercontent.com/IsidoreBeautrelet/economictheoryblog/master/robust_summary.R"

#create factor variable for region
data <- data %>%
  dplyr::mutate(region = case_when(
    reg_1 == 1 ~ 1,
    reg_2 == 1 ~ 2,
    reg_3 == 1 ~ 3,
    reg_4 == 1 ~ 4,
    reg_5 == 1 ~ 5,
    reg_6 == 1 ~ 6,
    reg_7 == 1 ~ 7,
    reg_8 == 1 ~ 8
  ),
  region = as.factor(region))

#Moral Values Only
mod.bail1.rf1 <- lm(bailout1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + fair_01*retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01, data=data)
summary(mod.bail1.rf1) 

eval(parse(text = getURL(url_robust, ssl.verifypeer = FALSE)),
     envir=.GlobalEnv)
b1.cluster <- summary(mod.bail1.rf1, cluster=c("region")) 
b1.cses <- coef(b1.cluster)[,2]

#Including Controls: Demographics, Economic Self-interest, Identity, Region Fixed Effects
mod.bail1.rf2 <- lm(bailout1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
b2.cluster <- summary(mod.bail1.rf2, cluster=c("region"))
b2.cses <- coef(b2.cluster)[,2]

#Including Controls: Trade ties instead of employment status (separate model due to branching in survey and resulting collinearity)
mod.bail1.rf3 <- lm(bailout1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 +  pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + trade_1 + trade_3 + trade_4 + trade_5 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
b3.cluster <- summary(mod.bail1.rf3, cluster=c("region"))
b3.cses <- coef(b3.cluster)[,2]

##Austerity##
#Moral Values Only
mod.aust1.rf1 <- lm(austerity1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01, data=data)
summary(mod.aust1.rf1) 
a1.cluster <- summary(mod.aust1.rf1, cluster=c("region")) 
a1.cses <- coef(a1.cluster)[,2]

#Including Controls: Demographics, Economic Self-interest, Identity, Region Fixed Effects
mod.aust1.rf2 <- lm(austerity1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.aust1.rf2)
a2.cluster <- summary(mod.aust1.rf2, cluster=c("region"))
a2.cses <- coef(a2.cluster)[,2]

#Including Controls: Trade ties instead of employment status (separate model due to branching in survey and resulting collinearity)
mod.aust1.rf3 <- lm(austerity1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + trade_1 + trade_3 + trade_4 + trade_5 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.aust1.rf3)
a3.cluster <- summary(mod.aust1.rf3, cluster=c("region"))
a3.cses <- coef(a3.cluster)[,2]

##Debt Relief##
#Moral Values Only
mod.debt1.rf1 <- lm(debtrelief1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01, data=data)
summary(mod.debt1.rf1) 
d1.cluster <- summary(mod.debt1.rf1, cluster=c("region")) 
d1.cses <- coef(d1.cluster)[,2]

#Including Controls: Demographics, Economic Self-interest, Identity, Region Fixed Effects
mod.debt1.rf2 <- lm(debtrelief1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.debt1.rf2)
d2.cluster <- summary(mod.debt1.rf2, cluster=c("region"))
d2.cses <- coef(d2.cluster)[,2]


#Including Controls: Trade ties instead of employment status (separate model due to branching in survey and resulting collinearity)
mod.debt1.rf3 <- lm(debtrelief1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + trade_1 + trade_3 + trade_4 + trade_5 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.debt1.rf3)
d3.cluster <- summary(mod.debt1.rf3, cluster=c("region"))
d3.cses <- coef(d3.cluster)[,2]

stargazer(mod.bail1.rf1, mod.bail1.rf2, mod.bail1.rf3, 
          mod.aust1.rf1, mod.aust1.rf2, mod.aust1.rf3, 
          mod.debt1.rf1, mod.debt1.rf2, mod.debt1.rf3,
          title="Correlates of Support for Bailout, Austerity, and Debt Forgiveness", 
          omit.stat=c("LL", "ser", "f"), 
          style="apsr", 
          digits=3, 
          label="tab:clusterses",
          se=list(b1.cses, b2.cses, b3.cses, a1.cses, a2.cses, a3.cses, d1.cses, d2.cses, d3.cses),
          covariate.labels=c("Caring", 
                             "Fairness", 
                             "Authority", 
                             "Retribution", 
                             "National Attachment", 
                             "European Attachment", 
                             "Cosmopolitanism", 
                             "Knowledge", 
                             "Interest", 
                             "SPD", 
                             "Linke", 
                             "Gr\"{u}ne", 
                             "FPD", 
                             "AfD", 
                             "Other Party", 
                             "Age", 
                             "Male", 
                             "Owns Stocks", 
                             "Secondary Educ. Certificate", 
                             "Higher Educ. Certificate", 
                             "Completed Vocational Training",
                             "Completed University", 
                             "15000-29999{euro}", 
                             "30000-49999{euro}", 
                             "50000-99999{euro}", 
                             "Over 100000{euro}", 
                             "Full Time", 
                             "Part Time", 
                             "Student", 
                             "Retired", 
                             "trade_1", 
                             "Weak Trade Ties", 
                             "Strong Trade Ties",
                             "Very Strong Trade Ties", 
                             "Regulation Important", 
                             "More State Services"), 
          star.cutoffs=c(0.05, 0.01))



# Appendix Figures 1, 2, and 3: Linear Interactions ----------------------------------

## Figure 1: The Effect of Fairness Conditional on Retribution
bin.b.fr <- interflex::inter.binning(Y = "bailout1st_01", 
                                     D = "fair_01", 
                                     X = "retrib_01", 
                                     Z = c("harm_01",
                                           "auth_01",
                                           "natid_01",
                                           "eurid_01",
                                           "cosmo2_01",
                                           "knowall",
                                           "interested_01",
                                           "pid_2",
                                           "pid_3",
                                           "pid_4",
                                           "pid_5",
                                           "pid_6",
                                           "pid_7",
                                           "age",
                                           "Male",
                                           "stocks",
                                           "education_2",
                                           "education_3",
                                           "education_4",
                                           "education_5",
                                           "income_2",
                                           "income_3",
                                           "income_4",
                                           "income_5",
                                           "emp_1",
                                           "emp_2",
                                           "emp_3",
                                           "emp_4",
                                           "econ1_01",
                                           "econ4_01",
                                           "reg_1",
                                           "reg_2",
                                           "reg_3",
                                           "reg_4",
                                           "reg_5",
                                           "reg_7",
                                           "reg_8"),
                          data = data, nbins = 3, vartype = "homoscedastic", na.rm=TRUE,
                          Ylabel = "Bailout", Dlabel = "Fairness", Xlabel="Retribution")
#bin.b.fr$graph

bin.a.fr <- interflex::inter.binning(Y = "austerity1st_01", D = "fair_01", X = "retrib_01", 
                          Z = c("harm_01","auth_01","natid_01","eurid_01","cosmo2_01","knowall",
                                "interested_01","pid_2","pid_3","pid_4","pid_5","pid_6","pid_7",
                                "age","Male","stocks","education_2","education_3","education_4","education_5",
                                "income_2","income_3","income_4","income_5","emp_1","emp_2","emp_3","emp_4",
                                "econ1_01","econ4_01","reg_1","reg_2","reg_3","reg_4","reg_5","reg_7","reg_8"),
                          data = data, nbins = 3, vartype = "homoscedastic", na.rm=TRUE,
                          Ylabel = "Austerity", Dlabel = "Fairness", Xlabel="Retribution")

bin.d.fr <- interflex::inter.binning(Y = "debtrelief1st_01", D = "fair_01", X = "retrib_01", 
                          Z = c("harm_01","auth_01","natid_01","eurid_01","cosmo2_01","knowall",
                                "interested_01","pid_2","pid_3","pid_4","pid_5","pid_6","pid_7",
                                "age","Male","stocks","education_2","education_3","education_4","education_5",
                                "income_2","income_3","income_4","income_5","emp_1","emp_2","emp_3","emp_4",
                                "econ1_01","econ4_01","reg_1","reg_2","reg_3","reg_4","reg_5","reg_7","reg_8"),
                          data = data, nbins = 3, vartype = "homoscedastic", na.rm=TRUE,
                          Ylabel = "Debt Relief", Dlabel = "Fairness", Xlabel="Retribution")


grid.arrange(bin.b.fr$graph, bin.a.fr$graph, bin.d.fr$graph, ncol=3)

## Figure 2: The Effect of Caring Conditional on National Attachment
bin.b.cn <- interflex::inter.binning(Y = "bailout1st_01", D = "harm_01", X = "natid_01", 
                          Z = c("fair_01","auth_01","retrib_01","eurid_01","cosmo2_01","knowall",
                                "interested_01","pid_2","pid_3","pid_4","pid_5","pid_6","pid_7",
                                "age","Male","stocks","education_2","education_3","education_4","education_5",
                                "income_2","income_3","income_4","income_5","emp_1","emp_2","emp_3","emp_4",
                                "econ1_01","econ4_01","reg_1","reg_2","reg_3","reg_4","reg_5","reg_7","reg_8"),
                          data = data, nbins = 3, vartype = "homoscedastic", na.rm=TRUE,
                          Ylabel = "Bailout", Dlabel = "Caring", Xlabel="National Attachment")

bin.a.cn <- interflex::inter.binning(Y = "austerity1st_01", D = "harm_01", X = "natid_01", 
                          Z = c("fair_01","auth_01","retrib_01","eurid_01","cosmo2_01","knowall",
                                "interested_01","pid_2","pid_3","pid_4","pid_5","pid_6","pid_7",
                                "age","Male","stocks","education_2","education_3","education_4","education_5",
                                "income_2","income_3","income_4","income_5","emp_1","emp_2","emp_3","emp_4",
                                "econ1_01","econ4_01","reg_1","reg_2","reg_3","reg_4","reg_5","reg_7","reg_8"),
                          data = data, nbins = 3, vartype = "homoscedastic", na.rm=TRUE,
                          Ylabel = "Austerity", Dlabel = "Caring", Xlabel="National Attachment")


bin.d.cn <- interflex::inter.binning(Y = "debtrelief1st_01", D = "harm_01", X = "natid_01", 
                          Z = c("fair_01","auth_01","retrib_01","eurid_01","cosmo2_01","knowall",
                                "interested_01","pid_2","pid_3","pid_4","pid_5","pid_6","pid_7",
                                "age","Male","stocks","education_2","education_3","education_4","education_5",
                                "income_2","income_3","income_4","income_5","emp_1","emp_2","emp_3","emp_4",
                                "econ1_01","econ4_01","reg_1","reg_2","reg_3","reg_4","reg_5","reg_7","reg_8"),
                          data = data, nbins = 3, vartype = "homoscedastic", na.rm=TRUE,
                          Ylabel = "Debt Relief", Dlabel = "Caring", Xlabel="National Attachment")

grid.arrange(bin.b.cn$graph, bin.a.cn$graph, bin.d.cn$graph, ncol=3)


## Figure 3: The Effect of Fairness Conditional on National Attachment
bin.b.fn <- interflex::inter.binning(Y = "bailout1st_01", D = "fair_01", X = "natid_01", 
                          Z = c("harm_01","auth_01","retrib_01","eurid_01","cosmo2_01","knowall",
                                "interested_01","pid_2","pid_3","pid_4","pid_5","pid_6","pid_7",
                                "age","Male","stocks","education_2","education_3","education_4","education_5",
                                "income_2","income_3","income_4","income_5","emp_1","emp_2","emp_3","emp_4",
                                "econ1_01","econ4_01","reg_1","reg_2","reg_3","reg_4","reg_5","reg_7","reg_8"),
                          data = data, 
                          nbins = 3, 
                          vartype = "homoscedastic", 
                          na.rm=TRUE,
                          Ylabel = "Bailout", 
                          Dlabel = "Fairness", 
                          Xlabel="National Attachment")


bin.a.fn <- interflex::inter.binning(Y = "austerity1st_01", D = "fair_01", X = "natid_01", 
                          Z = c("harm_01","auth_01","retrib_01","eurid_01","cosmo2_01","knowall",
                                "interested_01","pid_2","pid_3","pid_4","pid_5","pid_6","pid_7",
                                "age","Male","stocks","education_2","education_3","education_4","education_5",
                                "income_2","income_3","income_4","income_5","emp_1","emp_2","emp_3","emp_4",
                                "econ1_01","econ4_01","reg_1","reg_2","reg_3","reg_4","reg_5","reg_7","reg_8"),
                          data = data, nbins = 3, vartype = "homoscedastic", na.rm=TRUE,
                          Ylabel = "Austerity", Dlabel = "Fairness", Xlabel="National Attachment")

bin.d.fn <- interflex::inter.binning(Y = "debtrelief1st_01", D = "fair_01", X = "natid_01", 
                          Z = c("harm_01","auth_01","retrib_01","eurid_01","cosmo2_01","knowall",
                                "interested_01","pid_2","pid_3","pid_4","pid_5","pid_6","pid_7",
                                "age","Male","stocks","education_2","education_3","education_4","education_5",
                                "income_2","income_3","income_4","income_5","emp_1","emp_2","emp_3","emp_4",
                                "econ1_01","econ4_01","reg_1","reg_2","reg_3","reg_4","reg_5","reg_7","reg_8"),
                          data = data, nbins = 3, vartype = "homoscedastic", na.rm=TRUE,
                          Ylabel = "Debt Relief", Dlabel = "Fairness", Xlabel="National Attachment")

grid.arrange(bin.b.fn$graph, bin.a.fn$graph, bin.d.fn$graph, ncol = 3)


# Appendix Table 8 --------------------------------------------------------

###  Alternative Specifications for Ideology and Region
### Models including continuous ideology and east/west dummy
# Continuous drops "Andere" ("Other")

# Continuous party ID, separate region variables
mod.bail1.rf4a <- lm(bailout1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 +  pid_cont + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.bail1.rf4a)

mod.aust1.rf4a <- lm(austerity1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 +  pid_cont + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)

mod.debt1.rf4a <- lm(debtrelief1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 +  pid_cont + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)


# Separate party ID variables, east/west dummy
mod.bail1.rf4b <- lm(bailout1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + east, data=data)


mod.aust1.rf4b <- lm(austerity1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + east, data=data)


mod.debt1.rf4b <- lm(debtrelief1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + east, data=data)

# Continuous party ID, east/west dummy
mod.bail1.rf4d <- lm(bailout1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_cont + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + east, data=data)
summary(mod.bail1.rf4d)

mod.aust1.rf4d <- lm(austerity1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_cont + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + east, data=data)
summary(mod.aust1.rf4d)

mod.debt1.rf4d <- lm(debtrelief1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_cont + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + east, data=data)
summary(mod.debt1.rf4d)

## Table 
# Note: The stargazer output was manually adjusted for inclusion in the manuscript/appendix.
# All changes are documented in the table caption.
stargazer(mod.bail1.rf4a, mod.bail1.rf4b, mod.bail1.rf4d,
          mod.aust1.rf4a, mod.aust1.rf4b, mod.aust1.rf4d,
          mod.debt1.rf4a, mod.debt1.rf4b, mod.debt1.rf4d,
          title="Correlates of Support for Bailout, Austerity, and Debt Forgiveness", 
          omit.stat=c("LL", "ser", "f"), 
          style="apsr", 
          digits=2, 
          label="tab:suppreg3",
          column.sep.width = "-1pt",
          font.size = "tiny",
          column.labels = c("Support Bailout", "Support Austerity Requirement", "Support Debt Forgiveness"),
          column.separate = c(3, 3, 3),
          dep.var.labels.include = FALSE,
          covariate.labels=c("Caring", 
                             "Authority", 
                             "National Attachment", 
                             "European Attachment", 
                             "Fairness", 
                             "Retribution", 
                             "Fairness $\\times$ Retribution",
                             "Cosmopolitanism", 
                             "Knowledge", 
                             "Interest",
                             "Left-Right",
                             "SPD",
                             "Linke",
                             "Gruene",
                             "FDP",
                             "AfD",
                             "Other",
                             "Age",
                             "Male",
                             "Owns Stocks", 
                             "Secondary Educ. Certificate", 
                             "Higher Educ. Certificate", 
                             "Completed Vocational Training",
                             "Completed University", 
                             "15000-29999\\EUR", 
                             "30000-49999\\EUR", 
                             "50000-99999\\EUR", 
                             "Over 100000\\EUR", 
                             "Full Time", 
                             "Part Time", 
                             "Student", 
                             "Retired", 
                             "Regulation Important", 
                             "More State Services",
                             "Region 1",
                             "Region 2",
                             "Region 3",
                             "Region 4",
                             "Region 5",
                             "Region 7",
                             "Region 8",
                             "Former GDR (incl. Berlin)"),
          order = c(1, 3, 5, 6, 2, 4, 42, 7:41, 43),
          star.char = c("*", "**"), 
          star.cutoffs = c(0.05, 0.01), 
          notes.append = FALSE, 
          notes = "*p$<$0.05; **p$<$0.01")



# Appendix Table 9 --------------------------------------------------------

### Dominant religion and bailout attitudes
# Bailout
mod.bail1.rf5a <- lm(bailout1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + catholic + protestant, data=data)
mod.bail1.rf5b <- lm(bailout1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 +  pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + catholic + protestant, data=data)

# Austerity
mod.aust1.rf5a <- lm(austerity1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + catholic + protestant, data=data)
mod.aust1.rf5b <- lm(austerity1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 +  pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + catholic + protestant, data=data)

# Debt relief
mod.debt1.rf5a <- lm(debtrelief1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + catholic + protestant, data=data)
mod.debt1.rf5b <- lm(debtrelief1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 +  pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + catholic + protestant, data=data)


# Note: The stargazer output was manually adjusted for inclusion in the manuscript/appendix.
# All changes are documented in the table caption.
stargazer(mod.bail1.rf5a, mod.bail1.rf5b,
          mod.aust1.rf5a, mod.aust1.rf5b,
          mod.debt1.rf5a, mod.debt1.rf5b,
          title="Testing for religious majorities in federal states", 
          omit.stat=c("LL", "ser", "f"), 
          style="apsr", 
          digits=3, 
          label="tab:suppreg3",
          column.sep.width = "-1pt",
          font.size = "tiny",
          column.labels = c("Support Bailout", "Support Austerity Requirement", "Support Debt Forgiveness"),
          column.separate = c(2, 2, 2),
          dep.var.labels.include = FALSE,
          covariate.labels=c("Caring", 
                             "Authority", 
                             "National Attachment", 
                             "European Attachment", 
                             "Fairness", 
                             "Retribution", 
                             "Fairness $\\times$ Retribution",
                             "Cosmopolitanism", 
                             "Knowledge", 
                             "Interest",
                             "SPD",
                             "Linke",
                             "Gruene",
                             "FDP",
                             "AfD",
                             "Other",
                             "Age",
                             "Male",
                             "Owns Stocks", 
                             "Secondary Educ. Certificate", 
                             "Higher Educ. Certificate", 
                             "Completed Vocational Training",
                             "Completed University", 
                             "15000-29999\\EUR", 
                             "30000-49999\\EUR", 
                             "50000-99999\\EUR", 
                             "Over 100000\\EUR", 
                             "Full Time", 
                             "Part Time", 
                             "Student", 
                             "Retired", 
                             "Regulation Important", 
                             "More State Services",
                             "Catholic majority",
                             "Protestant majority"),
          order = c(1, 3, 5, 6, 2, 4, 35),
          star.char = c("*", "**"), 
          star.cutoffs = c(0.05, 0.01), 
          notes.append = FALSE, 
          notes = "*p$<$0.05; **p$<$0.01")


# Appendix Table 10 -------------------------------------------------------
# Excluding Plausibly Posttreatment Control Variables
##First, Compare Table 1 Models to Estimates with Plausibly Posttreatment Variables Dropped##

##Support for Bailout##
#Version in Text: Including Controls: Demographics, Economic Self-interest, Identity, Region Fixed Effects
mod.bail1.2 <- lm(bailout1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + retrib_01*fair_01 +  natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.bail1.2)
#Drop Partisanship and Economic Attitudes#
mod.bail1.2pt <- lm(bailout1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + retrib_01*fair_01 +natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.bail1.2pt)
#Same, but Trade Ties instead of Employment Status
mod.bail1.3pt <- lm(bailout1st_01 ~ harm_01 + fair_01 + auth_01 +  retrib_01 + retrib_01*fair_01 +natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + trade_1 + trade_3 + trade_4 + trade_5 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.bail1.3pt)


##Austerity##
#Version in Text: Including Controls: Demographics, Economic Self-interest, Identity, Region Fixed Effects
mod.aust1.2 <- lm(austerity1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + retrib_01*fair_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.aust1.2)
#Drop Partisanship and Economic Attitudes#
mod.aust1.2pt <- lm(austerity1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + retrib_01*fair_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.aust1.2pt)
#Same, but Trade Ties instead of Employment Status
mod.aust1.3pt <- lm(austerity1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + retrib_01*fair_01 + natid_01 + eurid_01 +  cosmo2_01 + knowall + interested_01 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + trade_1 + trade_3 + trade_4 + trade_5 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.aust1.3pt)

##Debt Relief##
#Version in Text: Including Controls: Demographics, Economic Self-interest, Identity, Region Fixed Effects
mod.debt1.2 <- lm(debtrelief1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + retrib_01*fair_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.debt1.2)
#Drop Partisanship and Economic Attitudes#
mod.debt1.2pt <- lm(debtrelief1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + retrib_01*fair_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.debt1.2pt)
#Same, but Trade Ties instead of Employment Status
mod.debt1.3pt <- lm(debtrelief1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + retrib_01*fair_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + trade_1 + trade_3 + trade_4 + trade_5 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.debt1.3pt)

#Produces a mostly-formatted .tex table
stargazer(mod.bail1.2, mod.bail1.2pt, mod.bail1.3pt, 
          mod.aust1.2, mod.aust1.2pt, mod.aust1.3pt, 
          mod.debt1.2, mod.debt1.2pt, mod.debt1.3pt, 
          title="Correlates of Support for Bailout, Austerity, and Debt Forgiveness", 
          omit.stat=c("LL", "ser", "f"), 
          style="apsr", 
          digits=3, 
          label="tab:suppregpost",
          covariate.labels=c("Caring", 
                             "Fairness", 
                             "Authority", "Retribution", "National Attachment", "European Attachment", "Cosmopolitanism", 
                             "Knowledge", "Interest", "SPD", "Linke", "Gr\"{u}ne", "FPD", "AfD", "Other Party", "Age", "Male", "Owns Stocks", "Secondary Educ. Certificate", "Higher Educ. Certificate", "Completed Vocational Training",
                             "Completed University", "15000-29999{euro}", "30000-49999{euro}", "50000-99999{euro}", "Over 100000{euro}", "Full Time", "Part Time", "Student", "Retired", "trade_1", "Weak Trade Ties", "Strong Trade Ties",
                             "Very Strong Trade Ties", "Regulation Important", "More State Services"), 
          star.cutoffs=c(0.05, 0.01))


# Appendix Figure 4 -------------------------------------------------------
###Causal Mediation Models###
dat.mediate.bail <- data[which(!is.na(data$bailout1st_01)),]
dat.mediate.aust <- data[which(!is.na(data$austerity1st_01)),]
dat.mediate.debt <- data[which(!is.na(data$debtrelief1st_01)),]

#Dichotomous Party ID as mediator#
mod.m.bail <- glm(piddi ~ harm_01 + fair_01 + auth_01 + retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=dat.mediate.bail, family=binomial("probit"))
mod.bail <- lm(bailout1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + piddi + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=dat.mediate.bail)

mod.m.aust <- glm(piddi ~ harm_01 + fair_01 + auth_01 + retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=dat.mediate.aust, family=binomial("probit"))
mod.aust <- lm(austerity1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + piddi + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=dat.mediate.aust)

mod.m.debt <- glm(piddi ~ harm_01 + fair_01 + auth_01 + retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=dat.mediate.debt, family=binomial("probit"))
mod.debt <- lm(debtrelief1st_01 ~ harm_01 + fair_01 + auth_01 +  retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + piddi + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=dat.mediate.debt)

# Bailout
harm.mod.bail <- mediation::mediate(mod.m.bail, mod.bail, sims=1500, boot=FALSE, treat="harm_01", mediator="piddi")
fair.mod.bail <- mediation::mediate(mod.m.bail,mod.bail, sims=1500, boot=FALSE, treat="fair_01", mediator="piddi")
authority.mod.bail <- mediation::mediate(mod.m.bail,mod.bail, sims=1500, boot=FALSE, treat="auth_01", mediator="piddi")
retrib.mod.bail <- mediation::mediate(mod.m.bail,mod.bail, sims=1500, boot=FALSE, treat="retrib_01", mediator="piddi")
natid.mod.bail <- mediation::mediate(mod.m.bail,mod.bail, sims=1500, boot=FALSE, treat="natid_01", mediator="piddi")
eurid.mod.bail <- mediation::mediate(mod.m.bail,mod.bail, sims=1500, boot=FALSE, treat="eurid_01", mediator="piddi")

# Austerity
harm.mod.aust <- mediation::mediate(mod.m.aust,mod.aust, sims=1500, boot=FALSE, treat="harm_01", mediator="piddi")
fair.mod.aust <- mediation::mediate(mod.m.aust,mod.aust, sims=1500, boot=FALSE, treat="fair_01", mediator="piddi")
authority.mod.aust <- mediation::mediate(mod.m.aust,mod.aust, sims=1500, boot=FALSE, treat="auth_01", mediator="piddi")
retrib.mod.aust <- mediation::mediate(mod.m.aust,mod.aust, sims=1500, boot=FALSE, treat="retrib_01", mediator="piddi")
natid.mod.aust <- mediation::mediate(mod.m.aust,mod.aust, sims=1500, boot=FALSE, treat="natid_01", mediator="piddi")
eurid.mod.aust <- mediation::mediate(mod.m.aust,mod.aust, sims=1500, boot=FALSE, treat="eurid_01", mediator="piddi")

# Debt relief
harm.mod.debt <- mediation::mediate(mod.m.debt,mod.debt, sims=1500, boot=FALSE, treat="harm_01", mediator="piddi")
fair.mod.debt <- mediation::mediate(mod.m.debt,mod.debt, sims=1500, boot=FALSE, treat="fair_01", mediator="piddi")
authority.mod.debt <- mediation::mediate(mod.m.debt,mod.debt, sims=1500, boot=FALSE, treat="auth_01", mediator="piddi")
retrib.mod.debt <- mediation::mediate(mod.m.debt,mod.debt, sims=1500, boot=FALSE, treat="retrib_01", mediator="piddi")
natid.mod.debt <- mediation::mediate(mod.m.debt,mod.debt, sims=1500, boot=FALSE, treat="natid_01", mediator="piddi")
eurid.mod.debt <- mediation::mediate(mod.m.debt,mod.debt, sims=1500, boot=FALSE, treat="eurid_01", mediator="piddi")



###Version with National and European Identity
#Plotting Results
medResults <- function(mod){
  return(c(mod$d.avg, 
           mod$d.avg.ci, 
           mod$z.avg, 
           mod$z.avg.ci, 
           mod$tau.coef, 
           mod$tau.ci))
}

med.bail <- rbind(medResults(harm.mod.bail), 
                  medResults(fair.mod.bail), 
                  medResults(authority.mod.bail), 
                  medResults(retrib.mod.bail), 
                  medResults(natid.mod.bail), 
                  medResults(eurid.mod.bail))
med.aust <- rbind(medResults(harm.mod.aust), 
                  medResults(fair.mod.aust), 
                  medResults(authority.mod.aust), 
                  medResults(retrib.mod.aust), 
                  medResults(natid.mod.aust), 
                  medResults(eurid.mod.aust))
med.debt <- rbind(medResults(harm.mod.debt), 
                  medResults(fair.mod.debt), 
                  medResults(authority.mod.debt), 
                  medResults(retrib.mod.debt), 
                  medResults(natid.mod.debt), 
                  medResults(eurid.mod.debt))

par(mfrow=c(1,3), mar=c(5.5,2,4.1,0), oma=c(0,4,0,0))
#Bailout Panel
plot(0,0,xlim=c(-0.4,0.5), ylim=c(1,18), axes=FALSE, xlab="", ylab="", type="n", main="a) Support Bailout")
polygon(c(-0.5,0.5,0.5,-0.5),c(15.5,15.5,12.5,12.5), border=FALSE, col="gray92")
polygon(c(-0.5,0.5,0.5,-0.5),c(9.5,9.5,6.5,6.5), border=FALSE, col="gray92")
polygon(c(-0.5,0.5,0.5,-0.5),c(3.5,3.5,0.5,0.5), border=FALSE, col="gray92")

for (i in 1:6){
  for (j in c(1,4,7)){
    points(med.bail[i,j],(18-((i-1)*3+(j-1)/3)), pch=16)
    lines(c(med.bail[i,j+1], med.bail[i,j+2]),c(rep(18-((i-1)*3+(j-1)/3),2)))
  }
}
abline(v=0)
axis(1, xlab="Effect size")
for (i in seq(18,3,by=-3)){
  text(c("ACME", "Direct", "Total"),x=-0.4,y=c(i,i-1,i-2),cex=0.7)
}
mtext(c("Caring", "Fairness", "Authority", "Retribution", "National \n Attachment", "European \n Attachment"),side=2, at=seq(17,2,by=-3),line=2.5)
mtext(c("Effect Size"), side=1, line=3)

#Austerity Panel
plot(0,0,xlim=c(-0.4,0.5), ylim=c(1,18), axes=FALSE, xlab="", ylab="", type="n", main="b) Support Austerity")
polygon(c(-0.5,0.5,0.5,-0.5),c(15.5,15.5,12.5,12.5), border=FALSE, col="gray92")
polygon(c(-0.5,0.5,0.5,-0.5),c(9.5,9.5,6.5,6.5), border=FALSE, col="gray92")
polygon(c(-0.5,0.5,0.5,-0.5),c(3.5,3.5,0.5,0.5), border=FALSE, col="gray92")

for (i in 1:6){
  for (j in c(1,4,7)){
    points(med.aust[i,j],(18-((i-1)*3+(j-1)/3)), pch=16)
    lines(c(med.aust[i,j+1], med.aust[i,j+2]),c(rep(18-((i-1)*3+(j-1)/3),2)))
  }
}
abline(v=0)
axis(1, xlab="Effect size")
mtext(c("Effect Size"), side=1, line=3)

#Debt Relief panel
plot(0,0,xlim=c(-0.4,0.5), ylim=c(1,18), axes=FALSE, xlab="", ylab="", type="n", main="c) Support Debt Relief")
polygon(c(-0.5,0.5,0.5,-0.5),c(15.5,15.5,12.5,12.5), border=FALSE, col="gray92")
polygon(c(-0.5,0.5,0.5,-0.5),c(9.5,9.5,6.5,6.5), border=FALSE, col="gray92")
polygon(c(-0.5,0.5,0.5,-0.5),c(3.5,3.5,0.5,0.5), border=FALSE, col="gray92")

for (i in 1:6){
  for (j in c(1,4,7)){
    points(med.debt[i,j],(18-((i-1)*3+(j-1)/3)), pch=16)
    lines(c(med.debt[i,j+1], med.debt[i,j+2]),c(rep(18-((i-1)*3+(j-1)/3),2)))
  }
}
abline(v=0)
axis(1, xlab="Effect size")
mtext(c("Effect Size"), side=1, line=3)

## Figure 5 Causal Mediation##
### With continous party identification as the mediator
dat.mediate.id.bail <- dat.mediate.bail[which(!is.na(dat.mediate.bail$pid_cont)),]
dat.mediate.id.aust <- dat.mediate.aust[which(!is.na(dat.mediate.aust$pid_cont)),]
dat.mediate.id.debt <- dat.mediate.debt[which(!is.na(dat.mediate.debt$pid_cont)),]


mod.id.m.bail <- lm(pid_cont ~ harm_01 + fair_01 + auth_01 + retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=dat.mediate.id.bail)
mod.id.bail <- lm(bailout1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_cont + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=dat.mediate.id.bail)

mod.id.m.aust <- lm(pid_cont ~ harm_01 + fair_01 + auth_01 + retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=dat.mediate.id.aust)
mod.id.aust <- lm(austerity1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_cont + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=dat.mediate.id.aust)

mod.id.m.debt <- lm(pid_cont ~ harm_01 + fair_01 + auth_01 + retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=dat.mediate.id.debt)
mod.id.debt <- lm(debtrelief1st_01 ~ harm_01 + fair_01 + auth_01 +  retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_cont + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=dat.mediate.id.debt)

# Bailout
harm.mod.id.bail <- mediation::mediate(mod.id.m.bail, mod.id.bail, sims=1500, boot=FALSE, treat="harm_01", mediator="pid_cont")
fair.mod.id.bail <- mediation::mediate(mod.id.m.bail, mod.id.bail, sims=1500, boot=FALSE, treat="fair_01", mediator="pid_cont")
authority.mod.id.bail <- mediation::mediate(mod.id.m.bail, mod.id.bail, sims=1500, boot=FALSE, treat="auth_01", mediator="pid_cont")
retrib.mod.id.bail <- mediation::mediate(mod.id.m.bail, mod.id.bail, sims=1500, boot=FALSE, treat="retrib_01", mediator="pid_cont")
natid.mod.id.bail <- mediation::mediate(mod.id.m.bail, mod.id.bail, sims=1500, boot=FALSE, treat="natid_01", mediator="pid_cont")
eurid.mod.id.bail <- mediation::mediate(mod.id.m.bail, mod.id.bail, sims=1500, boot=FALSE, treat="eurid_01", mediator="pid_cont")

# Austerity
harm.mod.id.aust <- mediation::mediate(mod.id.m.aust, mod.id.aust, sims=1500, boot=FALSE, treat="harm_01", mediator="pid_cont")
fair.mod.id.aust <- mediation::mediate(mod.id.m.aust, mod.id.aust, sims=1500, boot=FALSE, treat="fair_01", mediator="pid_cont")
authority.mod.id.aust <- mediation::mediate(mod.id.m.aust, mod.id.aust, sims=1500, boot=FALSE, treat="auth_01", mediator="pid_cont")
retrib.mod.id.aust <- mediation::mediate(mod.id.m.aust, mod.id.aust, sims=1500, boot=FALSE, treat="retrib_01", mediator="pid_cont")
natid.mod.id.aust <- mediation::mediate(mod.id.m.aust, mod.id.aust, sims=1500, boot=FALSE, treat="natid_01", mediator="pid_cont")
eurid.mod.id.aust <- mediation::mediate(mod.id.m.aust, mod.id.aust, sims=1500, boot=FALSE, treat="eurid_01", mediator="pid_cont")

# Debt relief
harm.mod.id.debt <- mediation::mediate(mod.id.m.debt, mod.id.debt, sims=1500, boot=FALSE, treat="harm_01", mediator="pid_cont")
fair.mod.id.debt <- mediation::mediate(mod.id.m.debt, mod.id.debt, sims=1500, boot=FALSE, treat="fair_01", mediator="pid_cont")
authority.mod.id.debt <- mediation::mediate(mod.id.m.debt, mod.id.debt, sims=1500, boot=FALSE, treat="auth_01", mediator="pid_cont")
retrib.mod.id.debt <- mediation::mediate(mod.id.m.debt, mod.id.debt, sims=1500, boot=FALSE, treat="retrib_01", mediator="pid_cont")
natid.mod.id.debt <- mediation::mediate(mod.id.m.debt, mod.id.debt, sims=1500, boot=FALSE, treat="natid_01", mediator="pid_cont")
eurid.mod.id.debt <- mediation::mediate(mod.id.m.debt, mod.id.debt, sims=1500, boot=FALSE, treat="eurid_01", mediator="pid_cont")


#Plotting Results
medResults <- function(mod){
  return(c(mod$d.avg, mod$d.avg.ci, mod$z.avg, mod$z.avg.ci, mod$tau.coef, mod$tau.ci))
}

med.bail <- rbind(medResults(harm.mod.id.bail), medResults(fair.mod.id.bail), medResults(authority.mod.id.bail), medResults(retrib.mod.id.bail), medResults(natid.mod.id.bail), medResults(eurid.mod.id.bail))
med.aust <- rbind(medResults(harm.mod.id.aust), medResults(fair.mod.id.aust), medResults(authority.mod.id.aust), medResults(retrib.mod.id.aust), medResults(natid.mod.id.aust), medResults(eurid.mod.id.aust))
med.debt <- rbind(medResults(harm.mod.id.debt), medResults(fair.mod.id.debt), medResults(authority.mod.id.debt), medResults(retrib.mod.id.debt), medResults(natid.mod.id.debt), medResults(eurid.mod.id.debt))

par(mfrow=c(1,3), mar=c(5.5,2,4.1,0), oma=c(0,4,0,0))
#Bailout Panel
plot(0,0,xlim=c(-0.4,0.5), ylim=c(1,18), axes=FALSE, xlab="", ylab="", type="n", main="a) Support Bailout")
polygon(c(-0.5,0.5,0.5,-0.5),c(15.5,15.5,12.5,12.5), border=FALSE, col="gray92")
polygon(c(-0.5,0.5,0.5,-0.5),c(9.5,9.5,6.5,6.5), border=FALSE, col="gray92")
polygon(c(-0.5,0.5,0.5,-0.5),c(3.5,3.5,0.5,0.5), border=FALSE, col="gray92")

for (i in 1:6){
  for (j in c(1,4,7)){
    points(med.bail[i,j],(18-((i-1)*3+(j-1)/3)), pch=16)
    lines(c(med.bail[i,j+1], med.bail[i,j+2]),c(rep(18-((i-1)*3+(j-1)/3),2)))
  }
}
abline(v=0)
axis(1, xlab="Effect size")
for (i in seq(18,3,by=-3)){
  text(c("ACME", "Direct", "Total"),x=-0.4,y=c(i,i-1,i-2),cex=0.7)
}
mtext(c("Caring", "Fairness", "Authority", "Retribution", "National \n Attachment", "European \n Attachment"),side=2, at=seq(17,2,by=-3),line=2.5)
mtext(c("Effect Size"), side=1, line=3)

#Austerity Panel
plot(0,0,xlim=c(-0.4,0.5), ylim=c(1,18), axes=FALSE, xlab="", ylab="", type="n", main="b) Support Austerity")
polygon(c(-0.5,0.5,0.5,-0.5),c(15.5,15.5,12.5,12.5), border=FALSE, col="gray92")
polygon(c(-0.5,0.5,0.5,-0.5),c(9.5,9.5,6.5,6.5), border=FALSE, col="gray92")
polygon(c(-0.5,0.5,0.5,-0.5),c(3.5,3.5,0.5,0.5), border=FALSE, col="gray92")

for (i in 1:6){
  for (j in c(1,4,7)){
    points(med.aust[i,j],(18-((i-1)*3+(j-1)/3)), pch=16)
    lines(c(med.aust[i,j+1], med.aust[i,j+2]),c(rep(18-((i-1)*3+(j-1)/3),2)))
  }
}
abline(v=0)
axis(1, xlab="Effect size")
mtext(c("Effect Size"), side=1, line=3)

#Debt Relief panel
plot(0,0,xlim=c(-0.4,0.5), ylim=c(1,18), axes=FALSE, xlab="", ylab="", type="n", main="c) Support Debt Relief")
polygon(c(-0.5,0.5,0.5,-0.5),c(15.5,15.5,12.5,12.5), border=FALSE, col="gray92")
polygon(c(-0.5,0.5,0.5,-0.5),c(9.5,9.5,6.5,6.5), border=FALSE, col="gray92")
polygon(c(-0.5,0.5,0.5,-0.5),c(3.5,3.5,0.5,0.5), border=FALSE, col="gray92")

for (i in 1:6){
  for (j in c(1,4,7)){
    points(med.debt[i,j],(18-((i-1)*3+(j-1)/3)), pch=16)
    lines(c(med.debt[i,j+1], med.debt[i,j+2]),c(rep(18-((i-1)*3+(j-1)/3),2)))
  }
}
abline(v=0)
axis(1, xlab="Effect size")
mtext(c("Effect Size"), side=1, line=3)


##Regulation is Important (econ4_01) as mediator
mod.m.bail.e <- lm(econ4_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=dat.mediate.bail)
mod.bail.e <- lm(bailout1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=dat.mediate.bail)

mod.m.aust.e <- lm(econ4_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=dat.mediate.aust)
mod.aust.e <- lm(austerity1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=dat.mediate.aust)

mod.m.debt.e <- lm(econ4_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=dat.mediate.debt)
mod.debt.e <- lm(debtrelief1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=dat.mediate.debt)

# bailout
harm.mod.bail.e <- mediation::mediate(mod.m.bail.e,mod.bail.e, sims=1500, boot=FALSE, treat="harm_01", mediator="econ4_01")
fair.mod.bail.e <- mediation::mediate(mod.m.bail.e,mod.bail.e, sims=1500, boot=FALSE, treat="fair_01", mediator="econ4_01")
authority.mod.bail.e <- mediation::mediate(mod.m.bail.e,mod.bail.e, sims=1500, boot=FALSE, treat="auth_01", mediator="econ4_01")
retrib.mod.bail.e <- mediation::mediate(mod.m.bail.e,mod.bail.e, sims=1500, boot=FALSE, treat="retrib_01", mediator="econ4_01")

# austerity
harm.mod.aust.e <- mediation::mediate(mod.m.aust.e,mod.aust.e, sims=1500, boot=FALSE, treat="harm_01", mediator="econ4_01")
fair.mod.aust.e <- mediation::mediate(mod.m.aust.e,mod.aust.e, sims=1500, boot=FALSE, treat="fair_01", mediator="econ4_01")
retrib.mod.aust.e <- mediation::mediate(mod.m.aust.e,mod.aust.e, sims=1500, boot=FALSE, treat="retrib_01", mediator="econ4_01")
authority.mod.aust.e <- mediation::mediate(mod.m.aust.e,mod.aust.e, sims=1500, boot=FALSE, treat="auth_01", mediator="econ4_01")

# debt relief
harm.mod.debt.e <- mediation::mediate(mod.m.debt.e,mod.debt.e, sims=1500, boot=FALSE, treat="harm_01", mediator="econ4_01")
fair.mod.debt.e <- mediation::mediate(mod.m.debt.e,mod.debt.e, sims=1500, boot=FALSE, treat="fair_01", mediator="econ4_01")
retrib.mod.debt.e <- mediation::mediate(mod.m.debt.e,mod.debt.e, sims=1500, boot=FALSE, treat="retrib_01", mediator="econ4_01")
authority.mod.debt.e <- mediation::mediate(mod.m.debt.e,mod.debt.e, sims=1500, boot=FALSE, treat="auth_01", mediator="econ4_01")

#Plotting Results
medResults <- function(mod){
  return(c(mod$d.avg, mod$d.avg.ci, mod$z.avg, mod$z.avg.ci, mod$tau.coef, mod$tau.ci))
}

med.bail.e <- rbind(medResults(harm.mod.bail.e), medResults(fair.mod.bail.e), medResults(authority.mod.bail.e), medResults(retrib.mod.bail.e))
med.aust.e <- rbind(medResults(harm.mod.aust.e), medResults(fair.mod.aust.e), medResults(authority.mod.aust.e), medResults(retrib.mod.aust.e))
med.debt.e <- rbind(medResults(harm.mod.debt.e), medResults(fair.mod.debt.e), medResults(authority.mod.debt.e), medResults(retrib.mod.debt.e))

par(mfrow=c(1,3), mar=c(5.3,1.1,4.1,0), oma=c(0,4,0,0))
#Bailout Panel
plot(0,0,xlim=c(-0.4,0.5), ylim=c(1,12), axes=FALSE, xlab="", ylab="", type="n", main="a) Support Bailout")
polygon(c(-0.5,0.5,0.5,-0.5),c(9.5,9.5,6.5,6.5), border=FALSE, col="gray92")
polygon(c(-0.5,0.5,0.5,-0.5),c(3.5,3.5,0.5,0.5), border=FALSE, col="gray92")

for (i in 1:4){
  for (j in c(1,4,7)){
    points(med.bail.e[i,j],(12-((i-1)*3+(j-1)/3)), pch=16)
    lines(c(med.bail.e[i,j+1], med.bail.e[i,j+2]),c(rep(12-((i-1)*3+(j-1)/3),2)))
  }
}
abline(v=0)
axis(1, xlab="Effect size")
for (i in seq(12,3,by=-3)){
  text(c("ACME", "Direct", "Total"),x=-0.4,y=c(i,i-1,i-2),cex=0.7)
}
mtext(c("Caring", "Fairness", "Authority", "Retribution"),side=2, at=seq(11,2,by=-3),line=2.5)
mtext(c("Effect Size"), side=1, line=3)

#Austerity Panel
plot(0,0,xlim=c(-0.4,0.5), ylim=c(1,12), axes=FALSE, xlab="", ylab="", type="n", main="b) Support Austerity")
polygon(c(-0.5,0.5,0.5,-0.5),c(9.5,9.5,6.5,6.5), border=FALSE, col="gray92")
polygon(c(-0.5,0.5,0.5,-0.5),c(3.5,3.5,0.5,0.5), border=FALSE, col="gray92")

for (i in 1:4){
  for (j in c(1,4,7)){
    points(med.aust.e[i,j],(12-((i-1)*3+(j-1)/3)), pch=16)
    lines(c(med.aust.e[i,j+1], med.aust.e[i,j+2]),c(rep(12-((i-1)*3+(j-1)/3),2)))
  }
}
abline(v=0)
axis(1, xlab="Effect size")
mtext(c("Effect Size"), side=1, line=3)

#Debt Relief panel
plot(0,0,xlim=c(-0.4,0.5), ylim=c(1,12), axes=FALSE, xlab="", ylab="", type="n", main="c) Support Debt Relief")
polygon(c(-0.5,0.5,0.5,-0.5),c(9.5,9.5,6.5,6.5), border=FALSE, col="gray92")
polygon(c(-0.5,0.5,0.5,-0.5),c(3.5,3.5,0.5,0.5), border=FALSE, col="gray92")

for (i in 1:4){
  for (j in c(1,4,7)){
    points(med.debt.e[i,j],(12-((i-1)*3+(j-1)/3)), pch=16)
    lines(c(med.debt.e[i,j+1], med.debt.e[i,j+2]),c(rep(12-((i-1)*3+(j-1)/3),2)))
  }
}
abline(v=0)
axis(1, xlab="Effect size")
mtext(c("Effect Size"), side=1, line=3)





 

# Appendix Tables 11, 12, and 13 ------------------------------------------
###Interactions with Interest###

##Table 11: Bailout##
#Including Controls: Demographics, Economic Self-interest, Identity, Region Fixed Effects
mod.harmint.lm  <- lm(bailout1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + harm_01*interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.harmint.lm)

mod.fairint.lm  <- lm(bailout1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + fair_01*retrib_01 + fair_01*interested_01 + retrib_01*interested_01 + fair_01*retrib_01*interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.fairint.lm)

mod.authint.lm  <- lm(bailout1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + auth_01*interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.authint.lm)

mod.natint.lm  <- lm(bailout1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + natid_01*interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.natint.lm)

mod.eurint.lm  <- lm(bailout1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + eurid_01*interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.eurint.lm)

#Produces a mostly-formatted .tex table
stargazer(mod.harmint.lm, 
          mod.fairint.lm, 
          mod.authint.lm, 
          mod.natint.lm, 
          mod.eurint.lm, 
          title="Do the effects of morals depend on interest?", 
          omit.stat=c("LL", "ser", "f"), 
          style="apsr", 
          digits=3, 
          label="tab:intbail1",
          covariate.labels=c("Caring", 
                             "Fairness", 
                             "Authority", 
                             "Retribution", 
                             "National Attachment", 
                             "European Attachment", 
                             "Cosmopolitanism", 
                             "Knowledge", "Interest"), 
          star.cutoffs=c(0.05, 0.01))


## Table 12: Austerity##
#Including Controls: Demographics, Economic Self-interest, Identity, Region Fixed Effects
mod.harmintaust.lm  <- lm(austerity1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + harm_01*interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.harmintaust.lm)

mod.fairintaust.lm  <- lm(austerity1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + fair_01*retrib_01 + fair_01*interested_01 + retrib_01*interested_01 + fair_01*retrib_01*interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.fairintaust.lm)

mod.authintaust.lm  <- lm(austerity1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + auth_01*interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.authintaust.lm)

mod.natintaust.lm  <- lm(austerity1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + natid_01*interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.natintaust.lm)

mod.eurintaust.lm  <- lm(austerity1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + eurid_01*interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.eurintaust.lm)

#Produces a mostly-formatted .tex table
stargazer(mod.harmintaust.lm, 
          mod.fairintaust.lm, 
          mod.authintaust.lm, 
          mod.natintaust.lm, 
          mod.eurintaust.lm, 
          title="Do the effects of morals depend on interest?", 
          omit.stat=c("LL", "ser", "f"), 
          style="apsr", 
          digits=3, 
          label="tab:intaust1",
          covariate.labels=c("Caring", 
                             "Fairness", 
                             "Authority", 
                             "Retribution", 
                             "National Attachment", 
                             "European Attachment", 
                             "Cosmopolitanism", 
                             "Knowledge", "Interest"), 
          star.cutoffs=c(0.05, 0.01))



## Table 13: Debt Relief ###
#Including Controls: Demographics, Economic Self-interest, Identity, Region Fixed Effects
mod.harmintdebt.lm  <- lm(debtrelief1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + harm_01*interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.harmintdebt.lm)

mod.fairintdebt.lm  <- lm(debtrelief1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + fair_01*interested_01 + fair_01*interested_01 + retrib_01*interested_01 + fair_01*retrib_01*interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.fairintdebt.lm)

mod.authintdebt.lm  <- lm(debtrelief1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + auth_01*interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.authintdebt.lm)

mod.natintdebt.lm  <- lm(debtrelief1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 +  natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + natid_01*interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.natintdebt.lm)

mod.eurintdebt.lm  <- lm(debtrelief1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + fair_01*retrib_01 + natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + eurid_01*interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.eurintdebt.lm)

#Produces a mostly-formatted .tex table
stargazer(mod.harmintdebt.lm, 
          mod.fairintdebt.lm, 
          mod.authintdebt.lm,  
          mod.natintdebt.lm, 
          mod.eurintdebt.lm, 
          title="Do the effects of morals depend on interest?", 
          omit.stat=c("LL", "ser", "f"), 
          style="apsr", 
          digits=3, 
          label="tab:debtint1",
          covariate.labels=c("Caring", 
                             "Fairness", 
                             "Authority", 
                             "Retribution", 
                             "National Attachment", 
                             "European Attachment", 
                             "Cosmopolitanism", 
                             "Knowledge", 
                             "Interest"), 
          star.cutoffs=c(0.05, 0.01))


## Table 14: see above

## Table 15: see above


# Appendix Table 16 -------------------------------------------------------

#Does authority depend on National Attachment?
#Bailout#
mod.authnat.lm  <- lm(bailout1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + natid_01 + auth_01*natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.authnat.lm)
#Austerity#
mod.authnataust.lm  <- lm(austerity1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + natid_01 + auth_01*natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.authnataust.lm)
#Debt Relief#
mod.authnatdebt.lm  <- lm(debtrelief1st_01 ~ harm_01 + fair_01 + auth_01 + retrib_01 + natid_01 + auth_01*natid_01 + eurid_01 + cosmo2_01 + knowall + interested_01 + pid_2 + pid_3 + pid_4 + pid_5 + pid_6 + pid_7 + age + Male + stocks + education_2 + education_3 + education_4 + education_5 + income_2 + income_3 + income_4 + income_5 + emp_1 + emp_2 + emp_3 + emp_4 + econ1_01 + econ4_01 + reg_1 + reg_2 + reg_3 + reg_4 + reg_5 + reg_7 + reg_8, data=data)
summary(mod.authnatdebt.lm)

#Produces a mostly-formatted .tex table
stargazer(mod.authnat.lm, mod.authnataust.lm, mod.authnatdebt.lm, 
          title="Does the Effect of Authority Depend on Identity?", 
          omit.stat=c("LL", "ser", "f"), 
          style="apsr", 
          digits=3, 
          label="tab:authnat",
          covariate.labels=c("Caring", 
                             "Fairness", 
                             "Authority", 
                             "Retribution", 
                             "National Attachment", 
                             "European Attachment", 
                             "Cosmopolitanism", 
                             "Knowledge", 
                             "Interest"), star.cutoffs=c(0.05, 0.01))

#Bailout
#Formatted for manuscript
abp <- interplot(m=mod.authnat.lm, 
                            var1="auth_01", 
                            var2="natid_01", 
                            esize=1.2, 
                 point = T) + 
  geom_point(size=4) + 
  ylab("Effect of Authority") + 
  theme_bw() + 
  theme(plot.margin=unit(c(1,1,1.5,1.2),"cm")) + 
  geom_hline(yintercept=0, linetype="dashed") + 
  ggtitle("a) Bailout")
abp2 <- abp + 
  scale_x_continuous(name="National Attachment", 
                     limits=c(0, 1), 
                     breaks=c(0, .167, 0.33, 0.5, 0.67, 0.83, 1), 
                     labels=c("0", "0.17", "0.33", "0.5", "0.67", "0.83", "1")) + 
  scale_y_continuous(limits=c(-.6,0.8)) +
  theme(axis.title.x = element_text(size=22), 
        axis.title.y = element_text(size=22), 
        axis.text.x = element_text(size=16, colour="black"), 
        axis.text.y=element_text(size=16, colour="black"),
        plot.title = element_text(size=22, colour="black", hjust=0.5))


#Austerity
#Formatted for manuscript
aap <- interplot(m=mod.authnataust.lm, 
                 var1="auth_01", 
                 var2="natid_01", 
                 esize=1.2,
                 point = T) + 
  geom_point(size=4) + 
  #ylab("Effect of Authority") + 
  theme_bw() + 
  theme(plot.margin=unit(c(1,1,1.5,1.2),"cm")) + 
  geom_hline(yintercept=0, linetype="dashed") + 
  ggtitle("b) Austerity")
aap2 <- aap + 
  scale_x_continuous(name="National Attachment", 
                     limits=c(0, 1), 
                     breaks=c(0, .17, 0.33, 0.5, 0.67, 0.83, 1), 
                     labels=c("0", "0.17", "0.33", "0.5", "0.67", "0.83", "1")) + 
  scale_y_continuous(limits=c(-.6,0.8)) +
  theme(axis.title.x = element_text(size=22), 
        axis.title.y = element_text(size=22), 
        axis.text.x = element_text(size=16, colour="black"), 
        axis.text.y=element_text(size=16, colour="black"),
        plot.title = element_text(size=22, colour="black", hjust=0.5))


#Debt Relief
#Formatted for manuscript
adp <- interplot(m=mod.authnatdebt.lm, 
                 var1="auth_01", 
                 var2="natid_01", 
                 esize=1.2,
                 point = T) + 
  geom_point(size=4) + 
  #ylab("Effect of Authority") + 
  theme_bw() + 
  theme(plot.margin=unit(c(1,1,1.5,1.2),"cm")) + 
  geom_hline(yintercept=0, linetype="dashed") + 
  ggtitle("c) Debt Relief")
adp2 <- adp + 
  scale_x_continuous(name="National Attachment", 
                     limits=c(0, 1), 
                     breaks=c(0, .17, 0.33, 0.5, 0.67, 0.83, 1), 
                     labels=c("0", "0.17", "0.33", "0.5", "0.67", "0.83", "1")) + 
  scale_y_continuous(limits=c(-.6,0.8)) +
  theme(axis.title.x = element_text(size=22), 
        axis.title.y = element_text(size=22), 
        axis.text.x = element_text(size=16, colour="black"), 
        axis.text.y=element_text(size=16, colour="black"),
        plot.title = element_text(size=22, colour="black", hjust=0.5))


grid.arrange(abp2, aap2, adp2, ncol=3)



#####################################
#####################################
# EOF
#####################################
#####################################

